@@ -26,12 +26,6 @@ func (addr UsbAddr) String() string {
 	return fmt.Sprintf("Bus %.3d Device %.3d", addr.Bus, addr.Address)
 }
 
-// MapKey returns a string suitable as a map key
-// It is not even guaranteed that this string is printable
-func (addr UsbAddr) MapKey() string {
-	return fmt.Sprintf("%d:%d", addr.Bus, addr.Address)
-}
-
 // Less returns true, if addr is "less" that addr2, for sorting
 func (addr UsbAddr) Less(addr2 UsbAddr) bool {
 	return addr.Bus < addr2.Bus ||
