@@ -35,6 +35,7 @@ type UsbTransport struct {
 	shutdown     chan struct{} // Closed by Shutdown()
 	connstate    *usbConnState // Connections state tracker
 	quirks       []Quirks      // Device quirks
+	deadline     time.Time     // Deadline for requests
 }
 
 // NewUsbTransport creates new http.RoundTripper backed by IPP-over-USB
@@ -198,11 +199,53 @@ func (transport *UsbTransport) connInUse() int {
 	return cap(transport.connPool) - len(transport.connPool)
 }
 
+// SetDeadline sets the deadline for all requests, submitted
+// via RoundTrip and RoundTripWithSession methods
+//
+// A deadline is an absolute time after which request processing
+// will fail instead of blocking
+//
+// This is useful only at initialization time and if some requests
+// were failed due to timeout, device reset is required, because
+// at this case synchronization with device will probably be lost
+//
+// A zero value for t means no timeout
+func (transport *UsbTransport) SetDeadline(t time.Time) {
+	transport.deadline = t
+}
+
+// DeadlineExpired reports if deadline previously set by SetDeadline()
+// is already expired
+func (transport *UsbTransport) DeadlineExpired() bool {
+	deadline := transport.deadline
+	return !deadline.IsZero() && time.Until(deadline) <= 0
+}
+
+// closeShutdownChan closes the transport.shutdown, which effectively
+// disables connections allocation (usbConnGet will return ErrShutdown)
+//
+// This function can be safely called multiple times (only the first
+// call closes the channel)
+//
+// Note, this function cannot be called simultaneously from
+// different threads. However, it's not a problem, because it
+// is only called from (*UsbTransport) Shutdown() and
+// (*UsbTransport) Close(), and both of these functions are
+// only called from the PnP thread context.
+func (transport *UsbTransport) closeShutdownChan() {
+	select {
+	case <-transport.shutdown:
+		// Channel already closed
+	default:
+		close(transport.shutdown)
+	}
+}
+
 // Shutdown gracefully shuts down the transport. If provided
 // context expires before shutdown completion, Shutdown
 // returns the Context's error
 func (transport *UsbTransport) Shutdown(ctx context.Context) error {
-	close(transport.shutdown)
+	transport.closeShutdownChan()
 
 	for {
 		n := transport.connInUse()
@@ -226,13 +269,18 @@ func (transport *UsbTransport) Shutdown(ctx context.Context) error {
 }
 
 // Close the transport
-func (transport *UsbTransport) Close() {
-	if transport.connInUse() > 0 {
+func (transport *UsbTransport) Close(reset bool) {
+	// Reset the device, if required
+	if transport.connInUse() > 0 || reset {
 		transport.log.Info('-', "%s: resetting %s",
 			transport.addr, transport.info.ProductName)
 		transport.dev.Reset()
 	}
 
+	// Wait until all connections become inactive
+	transport.Shutdown(context.Background())
+
+	// Destroy all connections and close the USB device
 	for _, conn := range transport.connList {
 		conn.destroy()
 	}
@@ -507,7 +555,14 @@ func (transport *UsbTransport) openUsbConn(
 	}
 
 	// Soft-reset interface
-	err = conn.iface.SoftReset()
+	//
+	// Note, disabled for now, because it causes problems
+	// with EPSON ET-4750 (see #17)
+	//
+	// May be in a future we will enable it conditionally,
+	// for some printer models (based on quirks)
+	//
+	// err = conn.iface.SoftReset()
 	if err != nil {
 		// Don't treat it too seriously
 		transport.log.Info('?', "USB[%d]: SOFT_RESET: %s", index, err)
@@ -525,6 +580,17 @@ ERROR:
 	return nil, err
 }
 
+// Compute Recv/Send timeout
+func (conn *usbConn) timeout() (tm time.Duration, expored bool) {
+	deadline := conn.transport.deadline
+	if deadline.IsZero() {
+		return
+	}
+
+	tm = time.Until(deadline)
+	return tm, tm <= 0
+}
+
 // Read from USB
 func (conn *usbConn) Read(b []byte) (int, error) {
 	conn.transport.connstate.beginRead(conn)
@@ -546,7 +612,12 @@ func (conn *usbConn) Read(b []byte) (int, error) {
 
 	backoff := time.Millisecond * 100
 	for {
-		n, err := conn.iface.Recv(b, 0)
+		tm, expired := conn.timeout()
+		if expired {
+			return 0, ErrInitTimedOut
+		}
+
+		n, err := conn.iface.Recv(b, tm)
 		conn.cntRecv += n
 
 		conn.transport.log.Add(LogTraceHTTP, '<',
@@ -577,7 +648,12 @@ func (conn *usbConn) Write(b []byte) (int, error) {
 	conn.transport.connstate.beginWrite(conn)
 	defer conn.transport.connstate.doneWrite(conn)
 
-	n, err := conn.iface.Send(b, 0)
+	tm, expired := conn.timeout()
+	if expired {
+		return 0, ErrInitTimedOut
+	}
+
+	n, err := conn.iface.Send(b, tm)
 	conn.cntSent += n
 
 	conn.transport.log.Add(LogTraceHTTP, '>',
